aboutsummaryrefslogtreecommitdiffstats
path: root/actionpack/lib/action_controller/base/render.rb
diff options
context:
space:
mode:
authorJeremy Kemper <jeremy@bitsweat.net>2009-04-21 16:02:30 -0700
committerJeremy Kemper <jeremy@bitsweat.net>2009-04-21 16:02:30 -0700
commitf49e3441280380ec810d54bd5a77a7e699415efb (patch)
tree6d5578830513259a3a3df0d7480f2a1d3b46cacc /actionpack/lib/action_controller/base/render.rb
parent504d16ccdfcd689eac31c1646957b06cc0ce55d1 (diff)
downloadrails-f49e3441280380ec810d54bd5a77a7e699415efb.tar.gz
rails-f49e3441280380ec810d54bd5a77a7e699415efb.tar.bz2
rails-f49e3441280380ec810d54bd5a77a7e699415efb.zip
Reinstate Base#render_to_string. Introduce AbstractController#render_to_string which stringifies render_to_body.
Diffstat (limited to 'actionpack/lib/action_controller/base/render.rb')
-rw-r--r--actionpack/lib/action_controller/base/render.rb14
1 files changed, 9 insertions, 5 deletions
diff --git a/actionpack/lib/action_controller/base/render.rb b/actionpack/lib/action_controller/base/render.rb
index 0d24f18633..604dd31930 100644
--- a/actionpack/lib/action_controller/base/render.rb
+++ b/actionpack/lib/action_controller/base/render.rb
@@ -306,9 +306,9 @@ module ActionController
(name.is_a?(String) ? name.sub(/^#{controller_path}\//, '') : name).to_s
end
- # Renders according to the same rules as <tt>render</tt>, but returns the result in a string instead
- # of sending it as the response body to the browser.
- def render_to_string(options = nil, &block) #:doc:
+ # Same rules as <tt>render</tt>, but returns a Rack-compatible body
+ # instead of sending the response.
+ def render_to_body(options = nil, &block) #:doc:
render(options, &block)
response.body
ensure
@@ -316,7 +316,11 @@ module ActionController
erase_render_results
reset_variables_added_to_assigns
end
-
+
+ def render_to_string(options = {})
+ Rack::Utils.body_to_s(render_to_body(options)).to_ary.join
+ end
+
# Clears the rendered results, allowing for another render to be performed.
def erase_render_results #:nodoc:
response.body = []
@@ -387,4 +391,4 @@ module ActionController
render_for_parts(parts, layout, options)
end
end
-end \ No newline at end of file
+end